@@ -29,8 +29,8 @@ COMMAND_UUID_WAVE_PLUS = UUID("b42e2d06-ade7-11e4-89d3-123b93f75cba")
 COMMAND_UUID_WAVE_MINI = UUID("b42e3ef4-ade7-11e4-89d3-123b93f75cba")
 
 # Atom
-COMMAND_UUID_WAVE_ENHANCE_NOTIFY = UUID("b42ebc9e-ade7-11e4-89d3-123b93f75cba")
-COMMAND_UUID_WAVE_ENHANCE = UUID("b42eb73a-ade7-11e4-89d3-123b93f75cba")
+COMMAND_UUID_ATOM_NOTIFY = UUID("b42ebc9e-ade7-11e4-89d3-123b93f75cba")
+COMMAND_UUID_ATOM = UUID("b42eb73a-ade7-11e4-89d3-123b93f75cba")
 
 """
 0 - 49 Bq/m3  (0 - 1.3 pCi/L):
